@@ -10,15 +10,18 @@ Log::ProgramInfo - log global info from a perl programs.
 # 0.1.2                 2015-04-04      John Macdonald   Minor cleanups to initial release
 # 0.1.3                 2015-04-09      John Macdonald   Rename s/JobInof/ProgramInfo/
 # 0.1.4                 2015-04-09      John Macdonald   Add README
+# 0.1.5                 2015-04-10      John Macdonald   Change log extension and env
+#                                                        variable names to reflect
+#                                                        the ProgramInfo name.
 #
 
 =head1 VERSION
 
-Version 0.1.4
+Version 0.1.5
 
 =cut
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5';
 
 use feature qw(say);
 use Data::Dumper;
@@ -63,7 +66,7 @@ use Fcntl qw(:flock);
 	    LOGDIR        defaults to . (the current directory when the program terminates)
 	    LOGDATE       defaults to the date that the program was started
 	    LOGNAME       defaults to the basename of the program
-		LOGEXT        defaults to ".jobinfolog"
+		LOGEXT        defaults to ".programinfo"
 
 	The -ARG specifiers in the "import" list can be used to over-ride these defaults.  Specifying:
 
@@ -83,7 +86,7 @@ use Fcntl qw(:flock);
 
 	-stdout           will cause the log to be sent to stdout instead of a file
 	-suppress         will suppress logging (unless environment variable
-                              LOGJOBINFO_SUPPRESS is explcitly set to 0 or null)
+                              LOGPROGRAMINFO_SUPPRESS is explcitly set to 0 or null)
 
                               Normally, neither -suppress nor -stdout will be set in the
                               use statement, and the environment variables can then be
@@ -93,17 +96,17 @@ use Fcntl qw(:flock);
                               For some programs, however, it may be desired to not normally
                               provide any logging.  Specifying -suppress will accomplish
                               this.  In such a case, setting the environment variable
-                              LOGJOBINFO_SUPPRESS=0 will over-ride that choice, causing
+                              LOGPROGRAMINFO_SUPPRESS=0 will over-ride that choice, causing
                               the log to be written (as specified by the other options
                               and environment variables).
 
 	Environment variables can over-ride some of these:
-	    LOGJOBINFO_SUPPRESS=x  boolean suppresses all logging if true
-	    LOGJOBINFO_STDOUT=x    boolean sets -stdout
-	    LOGJOBINFO_DIR=DIR     string  sets the target directory name
-	    LOGJOBINFO_FILE=FILE   string  sets the target filename LOGNAME
-	    LOGJOBINFO_EXT=EXT     string  sets the target extension
-	    LOGJOBINFO_DATE=DATE   string  sets the target filename LOGDATE selector
+	    LOGPROGRAMINFO_SUPPRESS=x  boolean suppresses all logging if true
+	    LOGPROGRAMINFO_STDOUT=x    boolean sets -stdout
+	    LOGPROGRAMINFO_DIR=DIR     string  sets the target directory name
+	    LOGPROGRAMINFO_FILE=FILE   string  sets the target filename LOGNAME
+	    LOGPROGRAMINFO_EXT=EXT     string  sets the target extension
+	    LOGPROGRAMINFO_DATE=DATE   string  sets the target filename LOGDATE selector
 
 =cut
 
@@ -129,19 +132,19 @@ BEGIN {
 		logname   => $progbase,
 		logdir    => ".",
 		logdate   => "date",
-		logext    => ".jobinfo",
+		logext    => ".programinfo",
 		stdout    => 0,
 		suppress  => 0,
 		importcnt => 0
 	);
 
 	%_omap = (
-		LOGJOBINFO_SUPPRESS => 'suppress',
-		LOGJOBINFO_STDOUT   => 'stdout',
-		LOGJOBINFO_DIR      => 'logdir',
-		LOGJOBINFO_FILE     => 'logname',
-		LOGJOBINFO_EXT      => 'logext',
-		LOGJOBINFO_DATE     => 'logdate'
+		LOGPROGRAMINFO_SUPPRESS => 'suppress',
+		LOGPROGRAMINFO_STDOUT   => 'stdout',
+		LOGPROGRAMINFO_DIR      => 'logdir',
+		LOGPROGRAMINFO_FILE     => 'logname',
+		LOGPROGRAMINFO_EXT      => 'logext',
+		LOGPROGRAMINFO_DATE     => 'logdate'
 	);
 }
 
